@@ -1,5 +1,5 @@
-__version__ = "0.0.45"
-__keywords__ = ["python cgi apache stream file cache server proxy http"]
+__version__ = "0.1.1"
+__keywords__ = ["python cgi apache stream file cache server proxy http cors"]
 
 
 # if not __version__.endswith(".0"):
