@@ -156,8 +156,8 @@ def _generate_headers():
 def _generate_response():
     _generate_headers()
     _print(__response.pop("content"))
-    status_code = __response.pop("status_code")
-    if not __response.pop("cache") and status_code >= 500 and status_code <= 599:
+    status_code = __response["status_code"]
+    if not __response["cache"] and status_code >= 500 and status_code <= 599:
         if status_code in http.client.responses:
             msg = http.client.responses[status_code]
             status_message = "<h1>{} {}</h1><br/><p>{}</p>".format(status_code, msg, "The server has no response regarding this error.")
@@ -321,6 +321,8 @@ def execute(
                     set_status(500)
                 except:
                     log(_traceback.format_exc())
+            finally:
+                __response.clear()
 
         __methods[method] = _execute
         return _execute
